@@ -7,15 +7,18 @@
 #include "exportaddressbookjobinterfaceimpl.h"
 #include "exportresourcearchivejob.h"
 
-#include <AkonadiCore/AgentManager>
+#include <Akonadi/AgentManager>
 #include <MailCommon/MailUtil>
 
 #include <KConfigGroup>
 
-#include <QStandardPaths>
 #include "resourceconverterimpl.h"
+#include <QStandardPaths>
 
-ExportAddressbookJobInterfaceImpl::ExportAddressbookJobInterfaceImpl(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep)
+ExportAddressbookJobInterfaceImpl::ExportAddressbookJobInterfaceImpl(QObject *parent,
+                                                                     Utils::StoredTypes typeSelected,
+                                                                     ArchiveStorage *archiveStorage,
+                                                                     int numberOfStep)
     : ExportAddressbookJobInterface(parent, typeSelected, archiveStorage, numberOfStep)
 {
 }
@@ -49,19 +52,16 @@ Akonadi::Collection::Id ExportAddressbookJobInterfaceImpl::convertFolderPathToCo
 
 void ExportAddressbookJobInterfaceImpl::exportResourceToArchive(const QString &archivePath, const QString &url, const QString &identifier)
 {
-  auto resourceJob = new ExportResourceArchiveJob(this);
-  resourceJob->setArchivePath(archivePath);
-  resourceJob->setUrl(url);
-  resourceJob->setIdentifier(identifier);
-  resourceJob->setArchive(archive());
-  resourceJob->setArchiveName(Utils::resourceAddressbookArchiveName());
-  connect(resourceJob, &ExportResourceArchiveJob::error, this,
-          &ExportAddressbookJobInterfaceImpl::error);
-  connect(resourceJob, &ExportResourceArchiveJob::info, this,
-          &ExportAddressbookJobInterfaceImpl::info);
-  connect(resourceJob, &ExportResourceArchiveJob::terminated, this,
-          &ExportAddressbookJobInterfaceImpl::slotAddressbookJobTerminated);
-  resourceJob->start();
+    auto resourceJob = new ExportResourceArchiveJob(this);
+    resourceJob->setArchivePath(archivePath);
+    resourceJob->setUrl(url);
+    resourceJob->setIdentifier(identifier);
+    resourceJob->setArchive(archive());
+    resourceJob->setArchiveName(Utils::resourceAddressbookArchiveName());
+    connect(resourceJob, &ExportResourceArchiveJob::error, this, &ExportAddressbookJobInterfaceImpl::error);
+    connect(resourceJob, &ExportResourceArchiveJob::info, this, &ExportAddressbookJobInterfaceImpl::info);
+    connect(resourceJob, &ExportResourceArchiveJob::terminated, this, &ExportAddressbookJobInterfaceImpl::slotAddressbookJobTerminated);
+    resourceJob->start();
 }
 
 QString ExportAddressbookJobInterfaceImpl::resourcePath(const QString &agentIdentifier, const QString &defaultPath) const
@@ -82,7 +82,8 @@ QString ExportAddressbookJobInterfaceImpl::adaptNewResourceUrl(bool overwriteRes
     return converter.adaptNewResourceUrl(overwriteResources, resourceConfig, storePath);
 }
 
-QString ExportAddressbookJobInterfaceImpl::createResource(const QString &resources, const QString &name, const QMap<QString, QVariant> &settings, bool synchronizeTree)
+QString
+ExportAddressbookJobInterfaceImpl::createResource(const QString &resources, const QString &name, const QMap<QString, QVariant> &settings, bool synchronizeTree)
 {
     Q_UNREACHABLE();
     return {};
